import type { FeatureFlags } from './FeatureFlags';
export type ModuleError = {
    type: 'no_camera';
    message?: string;
};
export type ModuleFinish = {
    type: 'finish';
    output: Output;
};
export type ModuleUnsupported = {
    type: 'unsupported';
    data?: unknown;
};
export type Outputs = ModuleFinish | ModuleUnsupported;
export type Output = unknown | ModuleError;
export type ExecutorMethod = 'bootstrap' | 'ping' | 'start';
export type RunnerMethod = 'captureModule.finish' | 'captureModule.error' | 'captureModule.unsupported' | 'crossDevice.start' | 'crossDevice.preload' | 'analytics.send' | 'analytics.userAnalytics' | 'navigation.back' | 'navigation.externalLink' | 'customCallback.invoke' | 'passkey.create' | 'passkey.get';
export type Configuration<T = unknown> = {
    translations: T;
    theme?: Theme;
    language?: string;
    workflowRunId?: string;
};
export type Input = Record<string, unknown>;
export type LocaleDirection = 'ltr' | 'rtl';
export type TranslationData<T> = T & {
    meta?: {
        legacy: Record<string, unknown>;
        fallback?: Record<string, unknown>;
        direction?: LocaleDirection;
        convertLegacyTranslations?: boolean;
    };
};
export type TranslationItem<T> = T | (() => Promise<T>);
export type Translations<T = unknown> = Record<string, TranslationItem<T>>;
export type ThemeConfig = Record<string, any>;
export type Theme = {
    name: 'light' | 'dark';
    config?: ThemeConfig;
};
export type Optional<T> = undefined | T;
export declare enum Platform {
    WEB = "web",
    IOS = "ios",
    ANDROID = "android"
}
type ExecutionContextConfiguration = {
    crossDevicePolicy?: CrossDevicePolicy;
    supportsCrossDevice?: boolean;
    supportsBack?: boolean;
    supportsExternalLink?: boolean;
};
export type CustomCallbacks = {
    names: string[];
    active: boolean;
};
export type ExecutionContext = {
    platform: Platform;
    version: string;
    module?: CaptureModule;
    configuration?: ExecutionContextConfiguration;
    customCallbacks?: CustomCallbacks;
    currentScriptHostname?: string;
};
export type UserDetails = {
    smsNumber?: string;
};
export type ClientConfiguration = {
    token: string;
    sdkToken: SdkToken;
    featureFlags: FeatureFlags;
    theme?: Theme;
    language?: string;
    translations?: Translations;
    analytics: {
        enabled: boolean;
        anonymousUuid: string;
        sessionUuid: string;
        workflowRunId: string | undefined;
        steps: LegacyStepDefinition[];
        source: {
            platform: string;
            version: string;
            sdk_environment: string;
            distribution_source: string;
        };
    };
    logger: {
        enabled: boolean;
        levels: string[];
    };
    enterpriseFeatures?: EnterpriseFeatures;
    crossDeviceClientIntroProductName?: string;
    crossDeviceClientIntroProductLogoSrc?: string;
    smsNumberCountryCode?: string;
    userDetails?: UserDetails;
};
export type SdkToken = {
    exp: number;
    payload: Payload;
    enterpriseFeatures?: TokenEnterpriseFeatures;
    urls: {
        detectDocumentUrl: URL;
        /**
         * @deprecated
         */
        syncUrl: URL;
        hostedSdkUrl: URL;
        authUrl: URL;
        onfidoApiUrl: URL;
        telephonyUrl: URL;
    };
};
export type UUID = string;
export type URL = string;
export type Payload = {
    applicantUuid: UUID;
    applicationId?: string;
    clientUuid: UUID;
    isSandbox: boolean;
    isTrial: boolean;
};
export type EnterpriseFeatures = {
    hideOnfidoLogo?: boolean;
    cobrand?: {
        text?: string;
    };
    logoCobrand?: {
        lightLogoSrc?: string;
        darkLogoSrc?: string;
    };
};
type TokenEnterpriseFeatures = {
    cobrand: boolean;
    logoCobrand: boolean;
    hideOnfidoLogo: boolean;
    useCustomizedApiRequests: boolean;
};
export type JWT = {
    exp: number;
    payload: {
        app: UUID;
        application_id?: string;
        client_uuid: UUID;
        is_sandbox: boolean;
        is_trial: boolean;
        ref: string;
        sardine_session: UUID;
    };
    enterprise_features: TokenEnterpriseFeatures;
    urls: {
        detect_document_url: URL;
        sync_url: URL;
        hosted_sdk_url: URL;
        auth_url: URL;
        onfido_api_url: URL;
        telephony_url: URL;
    };
};
export type TrackedEventTypes = 'screen' | 'action' | 'flow' | 'view';
export type AnalyticsEvent = {
    eventName: string;
    eventType: TrackedEventTypes;
};
export type UserAnalyticsEvent<N extends string = string, P extends Record<string, unknown> = Record<string, unknown>> = {
    eventName: N;
    properties: P;
};
export type DeviceTypes = 'desktop' | 'mobile';
export type TrackedEnvironmentData = {
    device?: DeviceTypes;
    os?: string;
    os_version?: string;
    browser?: string;
    browser_version?: string;
};
export type CrossDeviceInitialState = unknown;
export type CrossDeviceInput = {
    backActionType?: 'module' | 'cross-module';
};
export declare enum CaptureModuleType {
    HOSTED = "hosted",
    EXTERNAL = "external"
}
export type ModuleType<T extends CaptureModuleType> = {
    type: T;
};
export type HostedModule = {
    version?: string;
    module: string;
} & ModuleType<CaptureModuleType.HOSTED>;
export type ExternalModule = {
    url: string;
} & ModuleType<CaptureModuleType.EXTERNAL>;
export type CaptureModule = HostedModule | ExternalModule;
export type CrossDevicePolicy = 'enable' | 'force' | 'disable';
export type LegacyStepType = 'welcome' | 'complete' | 'face' | 'consent' | 'document' | 'poa';
export type LegacyStepDefinition = LegacyStepType | StepDefinition;
export type StepDefinition = {
    type: LegacyStepType | string;
    options?: Record<string, unknown>;
    module?: CaptureModule;
    /**
     * the key used to serialize the output for onComplete
     */
    key?: string;
};
export {};
